@@ -4,7 +4,8 @@ from torch import nn, einsum
 import torch.nn.functional as F
 
 from einops import rearrange
-from x_transformers import Encoder, Decoder
+from x_transformers import Encoder
+from dalle_pytorch.transformer import Transformer
 
 # helpers
 
@@ -50,7 +51,8 @@ class DiscreteVAE(nn.Module):
         codebook_dim = 512,
         hidden_dim = 64,
         num_layers = 3,
-        channels = 3
+        channels = 3,
+        temperature = 0.9
     ):
         super().__init__()
         assert log2(image_size).is_integer(), 'image size must be a power of 2'
@@ -59,6 +61,7 @@ class DiscreteVAE(nn.Module):
         self.image_size = image_size
         self.num_tokens = num_tokens
         self.num_layers = num_layers
+        self.temperature = temperature
         self.codebook = nn.Embedding(num_tokens, codebook_dim)
         
         hdim = hidden_dim
@@ -115,7 +118,7 @@ class DiscreteVAE(nn.Module):
         if return_logits:
             return logits # return logits for getting hard image indices for DALL-E training
 
-        soft_one_hot = F.gumbel_softmax(logits, tau = 1., dim=1)
+        soft_one_hot = F.gumbel_softmax(logits, tau = self.temperature, dim = 1)
         sampled = einsum('b n h w, n d -> b d h w', soft_one_hot, self.codebook.weight)
         out = self.decoder(sampled)
 
@@ -215,8 +218,12 @@ class DALLE(nn.Module):
         vae,
         num_text_tokens = 10000,
         text_seq_len = 256,
-        depth = 6,
-        heads = 8
+        depth,
+        heads = 8,
+        dim_head = 64,
+        reversible = False,
+        attn_dropout = 0.,
+        ff_dropout = 0
     ):
         super().__init__()
         assert isinstance(vae, DiscreteVAE), 'vae must be an instance of DiscreteVAE'
@@ -245,7 +252,16 @@ class DALLE(nn.Module):
             self.vae = vae
             self.image_emb = vae.codebook
 
-        self.transformer = Decoder(dim = dim, depth = depth, heads = heads)
+        self.transformer = Transformer(
+            dim = dim,
+            causal = True,
+            depth = depth,
+            heads = heads,
+            dim_head = dim_head,
+            reversible = reversible,
+            attn_dropout = attn_dropout,
+            ff_dropout = ff_dropout
+        )
 
         self.to_logits = nn.Sequential(
             nn.LayerNorm(dim),
